@@ -79,6 +79,7 @@ class SortableAdminBase(object):
             'adminsortable2/js/libs/jquery.ui.core-1.11.4.js',
             'adminsortable2/js/libs/jquery.ui.widget-1.11.4.js',
             'adminsortable2/js/libs/jquery.ui.mouse-1.11.4.js',
+            'adminsortable2/js/libs/jquery.ui.touch-punch-0.2.3.js',
             'adminsortable2/js/libs/jquery.ui.sortable-1.11.4.js',
         ]
         return super(SortableAdminBase, self).media + widgets.Media(css=css, js=js)
@@ -303,7 +304,7 @@ class SortableAdminMixin(SortableAdminBase):
         with transaction.atomic():
             try:
                 obj = model.objects.get(**obj_filters)
-            except model.MultipleObjectsReturned as exc:
+            except model.MultipleObjectsReturned:
                 msg = "Detected non-unique values in field '{0}' used for sorting this model.\nConsider to run \n"\
                       "    python manage.py reorder {1}\n"\
                       "to adjust this inconsistency."
